/**
 * Copyright (C) 2004 France Telecom R&D
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package org.objectweb.medor.expression.lib;

import org.objectweb.medor.expression.api.Expression;
import org.objectweb.medor.clone.lib.BasicCloneable;
import org.objectweb.jorm.type.api.PType;
import org.objectweb.util.monolog.Monolog;
import org.objectweb.util.monolog.api.Logger;

/**
 * Is an abstract common class for expression. It contains the type and
 * implements the cloning
 * @author S.Chassande-Barrioz
 */
public abstract class BasicExpression extends BasicCloneable implements Expression {

	protected PType type = null;
	transient protected Logger logger;

	public BasicExpression() {
		logger = Monolog.getMonologFactory().getLogger(getClass().getName());
	}

	public BasicExpression(PType type) {
		this();
		this.type = type;
	}

	public BasicExpression(BasicExpression be) {
		this(be.type);
	}

	public PType getType() {
		return type;
	}

	public Object clone(Object clone, java.util.Map obj2clone) throws CloneNotSupportedException {
		clone = super.clone(clone, obj2clone);
		((BasicExpression) clone).type = type;
		((BasicExpression) clone).logger = logger;
		return clone;
	}
}
