/**
 * MEDOR: Middleware Enabling Distributed Object Requests
 *
 * Copyright (C) 2001-2003 France Telecom R&D
 * Contact: alexandre.lefebvre@rd.francetelecom.com
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Initial developers: M. Alia, A. Lefebvre
 */

package org.objectweb.medor.expression.lib;

import org.objectweb.medor.expression.api.Expression;
import org.objectweb.medor.expression.api.UnaryOperator;
import org.objectweb.jorm.type.api.PType;

/**
 *
 * @author Sebastien Chassande-Barrioz
 */
public abstract class BasicUnaryOperator extends BasicOperator
		implements UnaryOperator {

	public BasicUnaryOperator() {
		super(new Expression[1]);
	}

	public BasicUnaryOperator(PType type) {
		super(type, new Expression[1]);
	}

	public BasicUnaryOperator(Expression e) {
		super(new Expression[]{e});
	}

	public BasicUnaryOperator(PType type, Expression e) {
		super(type, new Expression[]{e});
	}

    // IMPLEMENTATION OF THE Operator INTERFACE //
	//------------------------------------------//

    public int getOperandNumber() {
        return 1;
    }

    public Expression getExpression(int idx)
        throws ArrayIndexOutOfBoundsException {
        if (idx == 0)
            return getExpression();
        else
            throw new ArrayIndexOutOfBoundsException(idx);
    }

    public void setExpression(int idx, Expression exp)
        throws ArrayIndexOutOfBoundsException{
        if (idx == 0)
            setExpression(exp);
        else
            throw new ArrayIndexOutOfBoundsException(idx);
    }

    // IMPLEMENTATION OF THE UaryOperator INTERFACE //
    //------------------------------------------------//

    public void setExpression(Expression e) throws IllegalStateException {
        if (!verified){
            expressions[0] = e;
        }
		else
			throw new IllegalStateException("Compiled expression can't be modified");
    }

    public Expression getExpression() {
        return expressions[0];
    }

}
