/**
 * MEDOR: Middleware Enabling Distributed Object Requests
 *
 * Copyright (C) 2001-2003 France Telecom R&D
 * Contact: alexandre.lefebvre@rd.francetelecom.com
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Initial developers: M. Alia, A. Lefebvre, S. Chassande-Barrioz
 */
package org.objectweb.medor.expression.lib;

import org.objectweb.medor.expression.api.Expression;
import org.objectweb.medor.expression.api.ExpressionException;
import org.objectweb.medor.expression.api.MalformedExpressionException;
import org.objectweb.medor.expression.api.Operand;
import org.objectweb.medor.expression.api.Operator;
import org.objectweb.medor.expression.api.ParameterOperand;

/**
 * @author S.Chassande-Barrioz
 */
public class Like
	extends BasicOperator
	implements Operator {

	boolean not = false;

	public Like() {
	}

	public Like(Expression str, Expression pattern, Expression escape) {
		super(new Expression[] {str, pattern, escape});
	}

	public Like(Expression str, Expression pattern, Expression escape, boolean not) {
		super(new Expression[] {str, pattern, escape});
		this.not = not;
	}

	public Like(Expression str, Expression pattern) {
		super(new Expression[] {str, pattern});
	}

	public Like(Expression str, Expression pattern, boolean not) {
		super(new Expression[] {str, pattern});
		this.not = not;
	}

	public Object clone(Object clone, java.util.Map obj2clone) throws CloneNotSupportedException {
		clone = super.clone(clone, obj2clone);
		((Like) clone).not = not;
		return clone;
	}

	// IMPLEMENTATION OF THE Operator INTERFACE //
	//------------------------------------------//

	public String getOperatorString() {
		return (not ? "NOT LIKE" : "LIKE");
	}

	public Operand compileExpression()
		throws ExpressionException, MalformedExpressionException {
		throw new ExpressionException("Not yet implemented");
	}


	public Operand getResult() throws IllegalStateException {
		return null;
	}

	public org.objectweb.medor.expression.api.Operand
			evaluate(ParameterOperand[] values, Object o)
		throws ExpressionException {
		//TODO Implement Like operator
		throw new ExpressionException("Not yet implemented");
	}
}
