/**
 * Copyright (C) 2001-2005 France Telecom R&D
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *
 *
 * Authors: S.Chassande-Barrioz.
 * Created on 15 fvr. 2005
 *
 */
package org.objectweb.medor.expression.lib;

import org.objectweb.jorm.type.api.PType;
import org.objectweb.jorm.type.api.PTypeSpace;
import org.objectweb.medor.expression.api.Expression;
import org.objectweb.medor.expression.api.ExpressionException;
import org.objectweb.medor.expression.api.MalformedExpressionException;
import org.objectweb.medor.expression.api.Operand;
import org.objectweb.medor.expression.api.ParameterOperand;

/**
 * 
 *
 * @author S.Chassande-Barrioz
 */
public class Round extends BasicOperator {
    
    int round = 0;
    
    public Round() {
    }

    public Round(Expression e) {
		this(e,0);
    }

    public Round(Expression e, int r) {
		super(new Expression[]{e});
		setRound(r);
    }

    public int getRound() {
        return round;
    }
    
    public void setRound(int r) {
        round = r;
    }
    
    public Operand compileExpression() throws ExpressionException,
            MalformedExpressionException {
		type = expressions[0].compileExpression().getType();
		switch(type.getTypeCode()) {
		case PType.TYPECODE_FLOAT:
		case PType.TYPECODE_DOUBLE:
	        if (round <= 0) {
	            type = PTypeSpace.LONG;
	        }
		}
        result = new BasicVariableOperand(type);
        return result;
    }
    public Operand evaluate(ParameterOperand[] values, Object o)
            throws ExpressionException {
        Operand sub = expressions[0].evaluate(values, o);
		switch(sub.getType().getTypeCode()) {
		case PType.TYPECODE_FLOAT:
	        result.setValue(Math.round(sub.getFloat()));
			break;
		case PType.TYPECODE_OBJFLOAT:
		    Float f = (Float) sub.getObject();
			if (f == null) {
			    result.setValue((Object) null);
			} else {
			    result.setValue((long) Math.round(f.floatValue()));
			}
			break;
		case PType.TYPECODE_DOUBLE:
	        result.setValue(Math.round(sub.getDouble()));
			break;
		case PType.TYPECODE_OBJDOUBLE:
		    Double d = (Double) sub.getObject();
			if (d == null) {
			    result.setValue((Object) null);
			} else {
			    result.setValue((long) Math.round(d.doubleValue()));
			}
			break;
        default:
		    return sub;
		}
		return result;
	}
    public String getOperatorString() {
        return "round";
    }
}
