/**
 * MEDOR: Middleware Enabling Distributed Object Requests
 *
 * Copyright (C) 2001-2005 France Telecom
 * Contact: alexandre.lefebvre@rd.francetelecom.com
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Initial developers: M. Alia, A. Lefebvre
 */
package org.objectweb.medor.expression.lib;

import org.objectweb.jorm.type.api.PType;
import org.objectweb.jorm.type.api.PTypeSpace;
import org.objectweb.medor.expression.api.CalculatedParameterOperand;
import org.objectweb.medor.expression.api.ExpressionException;
import org.objectweb.medor.expression.api.ParameterOperand;

/**
 * This class defines a parameter operand to use for string comparison such as
 * a like expression.
 * 
 * @author S.Chassande-Barrioz
 * @author A.Lefebvre
 */
public class StringComparatorParameterOperand 
	extends BasicParameterOperand
    implements CalculatedParameterOperand {
    
    String prefix;
    String suffix;

	public StringComparatorParameterOperand(BasicParameterOperand po, String prefix, String suffix) {
		super(po);
		this.prefix = prefix;
		this.suffix = suffix;
	}

	public StringComparatorParameterOperand(String name, String prefix, String suffix) {
		super(PTypeSpace.STRING, name);
		this.prefix = prefix;
		this.suffix = suffix;
	}

    
    /**
     * 
     */
    public void evaluate(ParameterOperand[] pos) throws ExpressionException {
        String res = null;
		for (int i = 0; i < pos.length; i++) {
			if (pos[i] != null
                    && name.equals(pos[i].getName())
				    && pos[i].getType().getTypeCode() == PType.TYPECODE_STRING) {
				res = pos[i].getString();
			}
		}
		if (res == null) {
			throw new ExpressionException("Impossible to evaluate this parameter wihtout the parameter " + name);
		}
		if (suffix != null) {
		    res += suffix; 
		}
		if (prefix != null) {
		    res = prefix + res; 
		}
        this.setValue(res);
    }
}
